icsemantic.catalog.tests.test_indexes.TestOntoCatalogIndexes

Package platecom :: Package ontocatalog :: Package tests :: Module test_indexes :: Class TestOntoCatalogIndexes |
[hide private]
[frames] | no frames]

# Class TestOntoCatalogIndexes

source code

    Products.PloneTestCase.PloneTestCase.PloneTestCase --+
                                                         |
                                  base.OntoCatalogTestCase --+
                                                             |
                                                            TestOntoCatalogIndexes

Testing OntoCatalog indexes

Instance Methods | [hide private]
test_synonyms_index_search(self) Test a catalog search using the SynonymIndex | source code
test_related_index_search(self) Test a catalog search using the RelatedIndex | source code
test_translation_index_search(self) Test a catalog search using the TranslationIndex | source code
Inherited from `base.OntoCatalogTestCase`: `setUp`